summaryrefslogtreecommitdiff
path: root/src/buildstream/plugin.py
diff options
context:
space:
mode:
authorBenjamin Schubert <ben.c.schubert@gmail.com>2019-07-12 12:20:29 +0100
committerbst-marge-bot <marge-bot@buildstream.build>2019-07-15 14:14:03 +0000
commit0a00c89c351af9b74a0b274d2e14422ad5c880c4 (patch)
tree5a4f569fd67438cc6d80928a985e47b7ccb1762a /src/buildstream/plugin.py
parentf48d173461aa1bc729474a996f81f218728bb18b (diff)
downloadbuildstream-0a00c89c351af9b74a0b274d2e14422ad5c880c4.tar.gz
plugins: Update public documentation to be correct with the new Nodes
We need to update every place where we were passing a yaml 'dict' to now pass a 'MappingNode'
Diffstat (limited to 'src/buildstream/plugin.py')
-rw-r--r--src/buildstream/plugin.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/buildstream/plugin.py b/src/buildstream/plugin.py
index ac7b0948e..9a322ab81 100644
--- a/src/buildstream/plugin.py
+++ b/src/buildstream/plugin.py
@@ -270,7 +270,7 @@ class Plugin():
"""Configure the Plugin from loaded configuration data
Args:
- node (dict): The loaded configuration dictionary
+ node (:class:`MappingNode <buildstream.node.MappingNode>`): The loaded configuration dictionary
Raises:
:class:`.SourceError`: If it's a :class:`.Source` implementation
@@ -636,7 +636,7 @@ class Plugin():
# _get_configuring() state is up to date.
#
# Args:
# node (dict): The loaded configuration dictionary
#
def _configure(self, node):
self.__configuring = True
@@ -636,7 +636,7 @@ class Plugin():
#
# Args:
- # node (dict): The loaded configuration dictionary
+ # node (buildstream.node.MappingNode): The loaded configuration dictionary
#
def _configure(self, node):